package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.MultiLayerMarkerSymbol;
import com.esri.arcgis.display.ArrowMarkerSymbol;
import com.esri.arcgis.display.IColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads multi layer marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MultiLayerMarkerSymbolReader implements ISymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(MultiLayerMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private Element renderer;
    private MultiLayerMarkerSymbol symbol;
    private MapToXMLUtils util;


    public MultiLayerMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerMarkerSymbol) {
            this.symbol = (MultiLayerMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerMarkerSymbol!");
        }
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.renderer = parent;
    }

    /**
     * Setter for XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws IOException {
        logger.debug("read()");
        Element symbolElement;
        try {
            symbolElement = util.addSymbol(renderer);
        }
        catch(Exception e) {
            e.printStackTrace();
            return null;
        }

        for(int i = 0; i < symbol.getLayerCount(); i++) {
            IMarkerSymbol sym = symbol.getLayer(i);
            if (sym instanceof ArrowMarkerSymbol) {
                ArrowMarkerSymbol arrow = (ArrowMarkerSymbol)sym;
                IColor c = arrow.getColor();
                symbolElement.setAttribute(
                    "name",
                    arrow.getNameString());
                symbolElement.setAttribute(
                    "length",
                    String.valueOf(arrow.getLength()));
                symbolElement.setAttribute(
                    "width",
                    String.valueOf(arrow.getWidth()));
                symbolElement.setAttribute(
                    "angle",
                    String.valueOf(arrow.getAngle()));
                symbolElement.setAttribute(
                    "size",
                    String.valueOf(arrow.getSize()));
                symbolElement.setAttribute(
                    "x_offset",
                    String.valueOf(arrow.getXOffset()));
                symbolElement.setAttribute(
                    "y_offset",
                    String.valueOf(arrow.getYOffset()));
                symbolElement.setAttribute(
                    "color",
                    String.valueOf(c.getRGB()));
                symbolElement.setAttribute(
                    "tranparency",
                    String.valueOf(c.getTransparency()));
                symbolElement.setAttribute("style", "arrow");
            }
        }
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
